@@ -5,8 +5,8 @@
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#include <KLocalizedString>
 #include <KAboutData>
+#include <KLocalizedString>
 
 #include <QApplication>
 #include <QCommandLineParser>
@@ -15,18 +15,20 @@
 #include "kapptemplate_version.h"
 #include "logging.h"
 
-
 int main(int argc, char **argv)
 {
     QApplication application(argc, argv);
     KLocalizedString::setApplicationDomain("kapptemplate");
 
-    KAboutData about(
-        "kapptemplate", i18n("KAppTemplate"), QStringLiteral(KAPPTEMPLATE_VERSION_STRING),
-        i18n("KAppTemplate is a KDE project template generator"),
-        KAboutLicense::GPL,
-        i18n("(C) 2008 Anne-Marie Mahfouf"), QString(), QString(),
-        "submit@bugs.kde.org");
+    KAboutData about("kapptemplate",
+                     i18n("KAppTemplate"),
+                     QStringLiteral(KAPPTEMPLATE_VERSION_STRING),
+                     i18n("KAppTemplate is a KDE project template generator"),
+                     KAboutLicense::GPL,
+                     i18n("(C) 2008 Anne-Marie Mahfouf"),
+                     QString(),
+                     QString(),
+                     "submit@bugs.kde.org");
     about.addAuthor(i18n("Anne-Marie Mahfouf"), QString(), "annma AT kde DOT org");
     about.addAuthor(i18n("Sean Wilson"), i18n("Icons from Oxygen Team icons"), "suseux AT googlemail DOT com");
 
